import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
  .domain(['apple', 'lemon'])
  .range(['#c11d1d', '#eae600']);

const radiusScale = scaleOrdinal()
  .domain(['apple', 'lemon'])
  .range([80, 50]);

export const fruitBowl = (selection, props) => {
  const { fruits, height, selectedFruit, hoverFruit, clickFruit } = props;
  
  const bowl = selection.selectAll('rect')
    .data([null])
    .enter().append('rect')
      .attr('y', 110)
      .attr('width', 920)
      .attr('height', 300)
      .attr('rx', 300 / 4);
  
  const generateTranslate = i => `translate(${i * 180 + 100},${height / 2})`;
  
  const groups = selection.selectAll('g')
    .data(fruits, (d,i) => d.id);
  
  //groupEnter is the entry stage
  const groupsEnter = groups.enter().append('g');  //Appending groups for each fruit to svg 
  
  groupsEnter
  	.attr('transform', (d, i) => generateTranslate(i) )  //Moving groups to correct location on initially
    .merge(groups) //Update Stage 
  			.on('mouseover', d => hoverFruit(d.id))  			
  			.on('mouseout', d => hoverFruit(null)) 
  			.on('click', d => clickFruit(d.id))	
  		.transition().duration(1000)
      	.attr('transform', (d, i) => generateTranslate(i) ); //Moving groups to correct location on update
    
  groupsEnter.append('circle')  //Appending circle of radius 0 for each group
  		.attr('r', 0) 
    .merge(groups.select('circle')) //Update Stage
  	.transition().duration(1000)
      .attr('r', d => radiusScale(d.type)) //updating circle radius with animation
      .attr('fill', d => colorScale(d.type))
  		.attr('stroke-width', 10)
  		.attr('stroke', d => d.id === selectedFruit ? 'black' : 'none');
  
  groupsEnter.append('text') //Appending text for each group
    .merge(groups.select('text'))
      .text(d => d.type)
      .attr('y', 120);
   	
  //groupExit is the exit stage
  const groupsExit = groups.exit(); 
  
  //Removing circle from the exit stage with animation
  groupsExit
  	.select('circle')
  		.transition().duration(1000)
  		.attr('r',0)
  	.remove();
  
  //Removing text from the exit stage 
  groupsExit
  	.select('text')
    .remove();
  
}